@@ -13,7 +13,7 @@ def start_trigger (logger = None):
 
 def wakeup (thunk = None):
 	global the_trigger, the_logger
-		
+
 	if the_trigger is None:
 		if thunk:
 			try:
@@ -21,7 +21,7 @@ def wakeup (thunk = None):
 			except:
 				if the_logger:
 					the_logger.trace ('wakeup')
-		return		
+		return
 
 	try:
 		the_trigger.pull_trigger(thunk)
@@ -34,8 +34,8 @@ def wakeup (thunk = None):
 		the_trigger.close ()
 		the_trigger = trigger ()
 		the_trigger.pull_trigger(thunk)
-			
+
 def wakeselect ():
-	for fd, obj in list(asyncore.socket_map.items()):
+	for fd, obj in asyncore.socket_map.items():
 		if hasattr(obj, "pull_trigger"):
 			obj.pull_trigger()
