@@ -128,7 +128,7 @@ class AsynConnect (asynchat.async_chat, BaseConnect):
             if self.errcode not in (704, 712, 722):
                 # controlled shutdown
                 self.logger (
-                    ".....socket %s has been closed (reason: %d)" % ("%s:%d" % self.address, self.errcode),
+                    "..socket %s has been closed%s" % ("%s:%d" % self.address, self.errcode != 700 and " (reason: %d)".format (self.errcode) or ''),
                     "info"
                 )
         # DO NOT Change any props, because may be request has been restarted
@@ -136,11 +136,11 @@ class AsynConnect (asynchat.async_chat, BaseConnect):
     def end_tran (self):
         if DEBUG:
             self.logger ('end_tran {rid:%s} %s' % (self.handler.request.meta.get ('req_id', -1), self.handler.request.uri), 'debug')
-        if not self.backend:
-            self.del_channel ()
         if not self.keep_connect:
             self.disconnect ()
-        self.set_active (False)
+        elif not self.backend:
+            self.del_channel ()
+        self.isactive () and self.set_active (False)
 
     def get_proto (self):
         with self.lock:
