@@ -28,7 +28,6 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		return _STATE_RETRY
 
 	def poll (self):
-		# 2 cases, if on requesting raise immediatly, else handle silently
 		try:
 			try:
 				if REREY_TEST and self.writable () and self.request.retry_count == 0:
@@ -65,8 +64,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		self.handle_expt ()
 
 	def handle_connect_event (self):
-		state = self.poll ()
-		if state == POLL_OK:
+		if self.poll () == POLL_OK:
 			self.handle_connect ()
 			self.connected = True
 			self.connecting = False
@@ -84,15 +82,13 @@ class AsynConnect (dbconnect.AsynDBConnect, asyncore.dispatcher):
 		self.create_cursor ()
 
 	def handle_read (self):
-		state = self.poll ()
-		if self.cur and state == POLL_OK:
+		if self.cur and self.poll () == POLL_OK:
 			self.set_event_time ()
 			self.has_result = True
 			self.end_tran ()
 
 	def handle_write (self):
-		state = self.poll ()
-		if state == POLL_OK:
+		if self.poll () == POLL_OK:
 			if self.cur is None:
 				self.create_cursor ()
 			self.set_event_time ()
@@ -197,4 +193,3 @@ else:
 
 	_STATE_OK = (POLL_OK, POLL_WRITE, POLL_READ)
 	_STATE_RETRY = -1
-	_STATE_IGNORE = -2
