@@ -124,17 +124,13 @@ class AsynConnect (dbconnect.AsynDBConnect, asynchat.async_chat):
 
 		if not self.num_elements:
 			self.has_result = True
-			self.close_case_with_end_tran ()
+			self.end_tran ()
 
-	def close_case (self):
+	def end_tran (self):
 		if self.request:
 			self.request.handle_result (None, self.expt, self.fetchall ())
 			self.request = None
-		self.set_active (False)
-
-	def end_tran (self):
-		if not self.backend:
-			self.del_channel ()
+		dbconnect.AsynDBConnect.end_tran (self)
 
 	def begin_tran (self, request):
 		dbconnect.AsynDBConnect.begin_tran (self, request)
