@@ -104,7 +104,7 @@ class DBConnect (baseconnect.BaseConnect):
 
     def disconnect (self):
         # keep request and active, just close temporary
-        self.close (deactive = True)
+        self.close (deactive = False)
 
     def isconnected (self):
         # self.connected should be defined at __init__ or asyncore
@@ -134,8 +134,7 @@ class DBConnect (baseconnect.BaseConnect):
     def end_tran (self):
         if self.expt:
             self.close ()
-        else:
-            self.set_active (False)
+        self.isactive () and self.set_active (False)
 
     #-----------------------------------------------------
     # DB methods
