@@ -34,9 +34,6 @@ class SynConnect (asynpsycopg2.AsynConnect):
 		self.connected = False
 		dbconnect.DBConnect.close (self, deactive)
 
-	def close_case (self):
-		asynpsycopg2.AsynConnect.close_case (self)
-
 	def connect (self):
 		try:
 			self.conn = sqlite3.connect (self.address, check_same_thread = False)
@@ -65,4 +62,4 @@ class SynConnect (asynpsycopg2.AsynConnect):
 		except:
 			self.handle_error ()
 		else:
-			self.close_case ()
+			self.end_tran ()
